@@ -9,5 +9,6 @@ class JsonDecoder:
     @classmethod
     def decode_mongodb(cls, mongodb_string):
         return json.loads(
-            mongodb_string, cls=MongodbDocDecoder,
+            mongodb_string,
+            cls=MongodbDocDecoder,
         )
