@@ -26,7 +26,9 @@ class LoggerUtil(object):
             # log_path.mkdir(parents=True, exist_ok=True)
             logger = logging.getLogger(log_file_name)
             fh = handlers.RotatingFileHandler(
-                log_path / f"{log_file_name}.log", maxBytes=10240 * 1000, backupCount=5,
+                log_path / f"{log_file_name}.log",
+                maxBytes=10240 * 1000,
+                backupCount=5,
             )
             fh.setLevel(logging.INFO)
             fh.setFormatter(formatter)
